# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageIntensityPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkNotImageFilterPython
else:
    import _itkNotImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterBPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.itkImageSourcePython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourceCommonPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython

def itkNotImageFilterIF2IF2_Superclass_New():
    return itkNotImageFilterIF2IF2_Superclass.New()

class itkNotImageFilterIF2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkNotImageFilterIF2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIF2IF2_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIF2IF2_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::NOT< float >
        GetFunctor(self) -> itk::Functor::NOT< float > const &
        """
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::NOT< float > const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIF2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIF2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIF2IF2_Superclass

        Create a new object of the class itkNotImageFilterIF2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIF2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIF2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIF2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIF2IF2_Superclass in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIF2IF2_Superclass_swigregister(itkNotImageFilterIF2IF2_Superclass)

def itkNotImageFilterIF3IF3_Superclass_New():
    return itkNotImageFilterIF3IF3_Superclass.New()

class itkNotImageFilterIF3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkNotImageFilterIF3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIF3IF3_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIF3IF3_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::NOT< float >
        GetFunctor(self) -> itk::Functor::NOT< float > const &
        """
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::NOT< float > const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIF3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIF3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIF3IF3_Superclass

        Create a new object of the class itkNotImageFilterIF3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIF3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIF3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIF3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIF3IF3_Superclass in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIF3IF3_Superclass_swigregister(itkNotImageFilterIF3IF3_Superclass)

def itkNotImageFilterISS2ISS2_Superclass_New():
    return itkNotImageFilterISS2ISS2_Superclass.New()

class itkNotImageFilterISS2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkNotImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::NOT< short >
        GetFunctor(self) -> itk::Functor::NOT< short > const &
        """
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::NOT< short > const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterISS2ISS2_Superclass

        Create a new object of the class itkNotImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterISS2ISS2_Superclass in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterISS2ISS2_Superclass_swigregister(itkNotImageFilterISS2ISS2_Superclass)

def itkNotImageFilterISS3ISS3_Superclass_New():
    return itkNotImageFilterISS3ISS3_Superclass.New()

class itkNotImageFilterISS3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkNotImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::NOT< short >
        GetFunctor(self) -> itk::Functor::NOT< short > const &
        """
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::NOT< short > const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterISS3ISS3_Superclass

        Create a new object of the class itkNotImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterISS3ISS3_Superclass in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterISS3ISS3_Superclass_swigregister(itkNotImageFilterISS3ISS3_Superclass)

def itkNotImageFilterIUC2IUC2_Superclass_New():
    return itkNotImageFilterIUC2IUC2_Superclass.New()

class itkNotImageFilterIUC2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkNotImageFilterIUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::NOT< unsigned char >
        GetFunctor(self) -> itk::Functor::NOT< unsigned char > const &
        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::NOT< unsigned char > const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIUC2IUC2_Superclass

        Create a new object of the class itkNotImageFilterIUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIUC2IUC2_Superclass in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_Superclass_swigregister(itkNotImageFilterIUC2IUC2_Superclass)

def itkNotImageFilterIUC3IUC3_Superclass_New():
    return itkNotImageFilterIUC3IUC3_Superclass.New()

class itkNotImageFilterIUC3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkNotImageFilterIUC3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::NOT< unsigned char >
        GetFunctor(self) -> itk::Functor::NOT< unsigned char > const &
        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::NOT< unsigned char > const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIUC3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIUC3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIUC3IUC3_Superclass

        Create a new object of the class itkNotImageFilterIUC3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIUC3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIUC3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIUC3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIUC3IUC3_Superclass in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_Superclass_swigregister(itkNotImageFilterIUC3IUC3_Superclass)

def itkNotImageFilterIF2IF2_New():
    return itkNotImageFilterIF2IF2.New()

class itkNotImageFilterIF2IF2(itkNotImageFilterIF2IF2_Superclass):
    r"""Proxy of C++ itkNotImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIF2IF2_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIF2IF2_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_Clone(self)

    def SetBackgroundValue(self, backgroundValue):
        r"""
        SetBackgroundValue(self, backgroundValue)

        Parameters
        ----------
        backgroundValue: float const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_SetBackgroundValue(self, backgroundValue)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> float"""
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_GetBackgroundValue(self)

    def SetForegroundValue(self, foregroundValue):
        r"""
        SetForegroundValue(self, foregroundValue)

        Parameters
        ----------
        foregroundValue: float const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_SetForegroundValue(self, foregroundValue)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> float"""
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_GetForegroundValue(self)
    InputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIF2IF2_InputConvertibleToOutputCheck
    
    OutputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIF2IF2_OutputConvertibleToOutputCheck
    
    InputNotOperatorCheck = _itkNotImageFilterPython.itkNotImageFilterIF2IF2_InputNotOperatorCheck
    
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIF2IF2

        Create a new object of the class itkNotImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIF2IF2 in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIF2IF2_swigregister(itkNotImageFilterIF2IF2)

def itkNotImageFilterIF3IF3_New():
    return itkNotImageFilterIF3IF3.New()

class itkNotImageFilterIF3IF3(itkNotImageFilterIF3IF3_Superclass):
    r"""Proxy of C++ itkNotImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIF3IF3_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIF3IF3_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_Clone(self)

    def SetBackgroundValue(self, backgroundValue):
        r"""
        SetBackgroundValue(self, backgroundValue)

        Parameters
        ----------
        backgroundValue: float const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_SetBackgroundValue(self, backgroundValue)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> float"""
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_GetBackgroundValue(self)

    def SetForegroundValue(self, foregroundValue):
        r"""
        SetForegroundValue(self, foregroundValue)

        Parameters
        ----------
        foregroundValue: float const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_SetForegroundValue(self, foregroundValue)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> float"""
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_GetForegroundValue(self)
    InputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIF3IF3_InputConvertibleToOutputCheck
    
    OutputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIF3IF3_OutputConvertibleToOutputCheck
    
    InputNotOperatorCheck = _itkNotImageFilterPython.itkNotImageFilterIF3IF3_InputNotOperatorCheck
    
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIF3IF3

        Create a new object of the class itkNotImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIF3IF3 in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIF3IF3_swigregister(itkNotImageFilterIF3IF3)

def itkNotImageFilterISS2ISS2_New():
    return itkNotImageFilterISS2ISS2.New()

class itkNotImageFilterISS2ISS2(itkNotImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkNotImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterISS2ISS2_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterISS2ISS2_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_Clone(self)

    def SetBackgroundValue(self, backgroundValue):
        r"""
        SetBackgroundValue(self, backgroundValue)

        Parameters
        ----------
        backgroundValue: short const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_SetBackgroundValue(self, backgroundValue)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> short"""
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_GetBackgroundValue(self)

    def SetForegroundValue(self, foregroundValue):
        r"""
        SetForegroundValue(self, foregroundValue)

        Parameters
        ----------
        foregroundValue: short const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_SetForegroundValue(self, foregroundValue)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> short"""
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_GetForegroundValue(self)
    InputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_InputConvertibleToOutputCheck
    
    OutputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_OutputConvertibleToOutputCheck
    
    InputNotOperatorCheck = _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_InputNotOperatorCheck
    
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterISS2ISS2

        Create a new object of the class itkNotImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterISS2ISS2 in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterISS2ISS2_swigregister(itkNotImageFilterISS2ISS2)

def itkNotImageFilterISS3ISS3_New():
    return itkNotImageFilterISS3ISS3.New()

class itkNotImageFilterISS3ISS3(itkNotImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkNotImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterISS3ISS3_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterISS3ISS3_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_Clone(self)

    def SetBackgroundValue(self, backgroundValue):
        r"""
        SetBackgroundValue(self, backgroundValue)

        Parameters
        ----------
        backgroundValue: short const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_SetBackgroundValue(self, backgroundValue)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> short"""
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_GetBackgroundValue(self)

    def SetForegroundValue(self, foregroundValue):
        r"""
        SetForegroundValue(self, foregroundValue)

        Parameters
        ----------
        foregroundValue: short const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_SetForegroundValue(self, foregroundValue)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> short"""
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_GetForegroundValue(self)
    InputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_InputConvertibleToOutputCheck
    
    OutputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_OutputConvertibleToOutputCheck
    
    InputNotOperatorCheck = _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_InputNotOperatorCheck
    
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterISS3ISS3

        Create a new object of the class itkNotImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterISS3ISS3 in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterISS3ISS3_swigregister(itkNotImageFilterISS3ISS3)

def itkNotImageFilterIUC2IUC2_New():
    return itkNotImageFilterIUC2IUC2.New()

class itkNotImageFilterIUC2IUC2(itkNotImageFilterIUC2IUC2_Superclass):
    r"""Proxy of C++ itkNotImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIUC2IUC2_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIUC2IUC2_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_Clone(self)

    def SetBackgroundValue(self, backgroundValue):
        r"""
        SetBackgroundValue(self, backgroundValue)

        Parameters
        ----------
        backgroundValue: unsigned char const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_SetBackgroundValue(self, backgroundValue)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_GetBackgroundValue(self)

    def SetForegroundValue(self, foregroundValue):
        r"""
        SetForegroundValue(self, foregroundValue)

        Parameters
        ----------
        foregroundValue: unsigned char const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_SetForegroundValue(self, foregroundValue)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_GetForegroundValue(self)
    InputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_InputConvertibleToOutputCheck
    
    OutputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_OutputConvertibleToOutputCheck
    
    InputNotOperatorCheck = _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_InputNotOperatorCheck
    
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIUC2IUC2

        Create a new object of the class itkNotImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIUC2IUC2 in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIUC2IUC2_swigregister(itkNotImageFilterIUC2IUC2)

def itkNotImageFilterIUC3IUC3_New():
    return itkNotImageFilterIUC3IUC3.New()

class itkNotImageFilterIUC3IUC3(itkNotImageFilterIUC3IUC3_Superclass):
    r"""Proxy of C++ itkNotImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkNotImageFilterIUC3IUC3_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkNotImageFilterIUC3IUC3_Pointer"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_Clone(self)

    def SetBackgroundValue(self, backgroundValue):
        r"""
        SetBackgroundValue(self, backgroundValue)

        Parameters
        ----------
        backgroundValue: unsigned char const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_SetBackgroundValue(self, backgroundValue)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_GetBackgroundValue(self)

    def SetForegroundValue(self, foregroundValue):
        r"""
        SetForegroundValue(self, foregroundValue)

        Parameters
        ----------
        foregroundValue: unsigned char const &

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_SetForegroundValue(self, foregroundValue)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_GetForegroundValue(self)
    InputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_InputConvertibleToOutputCheck
    
    OutputConvertibleToOutputCheck = _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_OutputConvertibleToOutputCheck
    
    InputNotOperatorCheck = _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_InputNotOperatorCheck
    
    __swig_destroy__ = _itkNotImageFilterPython.delete_itkNotImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkNotImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkNotImageFilterIUC3IUC3

        Create a new object of the class itkNotImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkNotImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkNotImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkNotImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkNotImageFilterIUC3IUC3 in _itkNotImageFilterPython:
_itkNotImageFilterPython.itkNotImageFilterIUC3IUC3_swigregister(itkNotImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unary_functor_image_filter(*args: itkt.ImageLike,  functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnaryFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnaryFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unary_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.UnaryFunctorImageFilter
    unary_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unary_functor_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def not_image_filter(*args: itkt.ImageLike,  background_value: float=..., foreground_value: float=..., functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for NotImageFilter"""
    import itk

    kwarg_typehints = { 'background_value':background_value,'foreground_value':foreground_value,'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.NotImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def not_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageIntensity.NotImageFilter
    not_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    not_image_filter.__doc__ = filter_object.__doc__



